@@ -7,7 +7,7 @@ class ChangeDiameterTool(Tool):
     def __init__(self, manager):
         props = {'diameter': motorlib.properties.FloatProperty('Diameter', 'm', 0, 1)}
         super().__init__(manager,
-                         'Motor diameter',
+                         'Motor Diameter',
                          'Use this tool to set the diameter of all grains in the motor.',
                          props,
                          False)
